@@ -1,6 +1,6 @@
 %ISO/IEC DTR 13211-3
 
-:- module(dcg,[phrase/2,dcg_expand/1]).
+:- module(dcg,[phrase/2,phrase/3,dcg_expand/1]).
 
 :- op(1105,xfy,'|').
 
@@ -68,8 +68,8 @@ dcg_constr({_}).       % 7.14.7
 dcg_constr(call(_)).   % 7.14.8
 dcg_constr(phrase(_)). % 7.14.9
 dcg_constr(!).         % 7.14.10
-% dcg_constr(\+ _).    % 7.14.11 - not (existence implementation dep.)
-% dcg_constr((_->_)).  % 7.14.12 - if-then (existence implementation dep.)
+%dcg_constr(\+ _).      % 7.14.11 - not (existence implementation dep.)
+%dcg_constr((_->_)).    % 7.14.12 - if-then (existence implementation dep.)
 
 % The principal functor of the first argument indicates
 % the construct to be expanded.
